@@ -1,6 +1,6 @@
 /* ====================================================================
- * Copyright (c) 1999-2005 Ralf S. Engelschall <rse@engelschall.com>
- * Copyright (c) 1999-2005 The OSSP Project <http://www.ossp.org/>
+ * Copyright (c) 1999-2006 Ralf S. Engelschall <rse@engelschall.com>
+ * Copyright (c) 1999-2006 The OSSP Project <http://www.ossp.org/>
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -88,7 +88,7 @@ MM *mm_create(size_t usize, const char *file)
 }
 
 /*
- * Set permissions on memory pools underlaying disk files
+ * Set permissions on memory pool's underlaying disk files
  */
 int mm_permission(MM *mm, mode_t mode, uid_t owner, gid_t group)
 {
@@ -97,6 +97,19 @@ int mm_permission(MM *mm, mode_t mode, uid_t owner, gid_t group)
     return mm_core_permission((void *)mm, mode, owner, group);
 }
 
+/*
+ * Reset a memory pool.
+ */
+void mm_reset(MM *mm)
+{
+    if (mm == NULL)
+        return;
+    mm->mp_offset = SIZEOF_mem_pool;
+    mm->mp_freechunks.mc_usize = 0;
+    mm->mp_freechunks.mc_u.mc_next = NULL;
+    return;
+}
+
 /*
  * Destroy a memory pool
  */
