@@ -1,6 +1,6 @@
 /* ====================================================================
- * Copyright (c) 1999-2005 Ralf S. Engelschall <rse@engelschall.com>
- * Copyright (c) 1999-2005 The OSSP Project <http://www.ossp.org/>
+ * Copyright (c) 1999-2006 Ralf S. Engelschall <rse@engelschall.com>
+ * Copyright (c) 1999-2006 The OSSP Project <http://www.ossp.org/>
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -66,6 +66,14 @@ int MM_permission(mode_t mode, uid_t owner, gid_t group)
     return mm_permission(mm_global, mode, owner, group);
 }
 
+void MM_reset(void)
+{
+    if (mm_global == NULL)
+        return;
+    mm_reset(mm_global);
+    return;
+}
+
 void MM_destroy(void)
 {
     if (mm_global == NULL)
